"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const compression = require("compression");
const express = require("express");
const express_1 = require("express");
exports.Router = express_1.Router;
const logging_1 = require("../logging");
const logger = new logging_1.Logger('app');
function getApp(config, session) {
    return __awaiter(this, void 0, void 0, function* () {
        const app = express();
        app.use(express.json());
        app.use(express.urlencoded({ extended: true }));
        app.use(compression());
        // session, before anything else
        if (session) {
            if (session.middleware) {
                app.use(session.middleware);
            }
            // Session Initialisation Function
            if (session.initSessionFunction) {
                app.use((req, res, next) => {
                    session.initSessionFunction(req.session);
                    next();
                });
            }
        }
        // morgan
        if (config.node_env !== 'test') {
            app.use(require('morgan')('dev'));
        }
        // ping
        app.get('/ping', (req, res) => __awaiter(this, void 0, void 0, function* () { return res.send('pong\n'); }));
        // register middlewares
        if (config.middlewares) {
            for (const mw of config.middlewares) {
                logger.log(`Registering middleware ${mw}`);
                app.use(mw);
            }
        }
        // static (singular)
        if (config.static) {
            logger.log(`Registering static directory : "/" => "${config.static}"`);
            app.use(express.static(process.cwd() + '/' + config.static));
        }
        // statics (plural)
        if (config.statics && Object.keys(config.statics).length) {
            for (const s of config.statics) {
                logger.log(`Registering static directory : "${s.route}" => "${s.serve}"`);
                app.use(s.route, express.static(process.cwd() + '/' + s.serve));
            }
        }
        // routers
        for (const base in config.routers) {
            logger.log(`Providing route "${base}"`);
            app.use(base, config.routers[base]);
        }
        return app;
    });
}
exports.getApp = getApp;
//# sourceMappingURL=index.js.map