"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const connect = require("connect-redis");
const ExpressSession = require("express-session");
const redis_1 = require("redis");
const logging_1 = require("./logging");
const logger = new logging_1.Logger('session');
function getSession(config) {
    return __awaiter(this, void 0, void 0, function* () {
        const RedisStore = connect(ExpressSession);
        let connection;
        try {
            connection = yield getRedisClient(config);
        }
        catch (e) {
            throw e;
        }
        logger.success('Connected to redis.');
        const sessionOptions = {
            store: new RedisStore({ client: connection }),
            secret: 'thisissecret',
            resave: false,
            saveUninitialized: false
        };
        if (config.session_cookie_domain) {
            logger.log(`Using ${config.session_cookie_domain} for the session cookie domain.`);
            sessionOptions.cookie = {};
            sessionOptions.cookie.domain = config.session_cookie_domain;
        }
        else {
            logger.info('No session Cookie Domain set. It will use the whole url address (e.g. "www.example.com") provided by the requests.');
        }
        const middleware = ExpressSession(sessionOptions);
        return {
            type: 'redis',
            connection,
            middleware,
            initSessionFunction: config.initSessionFunction
        };
    });
}
exports.getSession = getSession;
;
function getRedisClient(config) {
    return new Promise((resolve, reject) => {
        const connectionHost = config.redis_host.split(':');
        const client = redis_1.createClient({
            host: connectionHost[0],
            port: connectionHost[1] ? parseInt(connectionHost[1]) : 6379
        });
        client
            .on('ready', () => resolve(client))
            .on('error', (e) => {
            client.quit();
            reject(e);
        })
            .on('end', () => logger.info('redis client has closed'));
    });
}
function closeSession(Session) {
    return __awaiter(this, void 0, void 0, function* () {
        Session.connection.quit();
    });
}
exports.closeSession = closeSession;
//# sourceMappingURL=redis-session.js.map